summaryrefslogtreecommitdiffstats
path: root/ktalkd/kcmktalkd/forwmachpage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ktalkd/kcmktalkd/forwmachpage.cpp')
-rw-r--r--ktalkd/kcmktalkd/forwmachpage.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/ktalkd/kcmktalkd/forwmachpage.cpp b/ktalkd/kcmktalkd/forwmachpage.cpp
index 6475927f..0a6337f7 100644
--- a/ktalkd/kcmktalkd/forwmachpage.cpp
+++ b/ktalkd/kcmktalkd/forwmachpage.cpp
@@ -26,7 +26,7 @@
#include <ksimpleconfig.h>
#include <klocale.h>
-KForwmachPageConfig::KForwmachPageConfig( QWidget *parent, const char* name,
+KForwmachPageConfig::KForwmachPageConfig( TQWidget *parent, const char* name,
KSimpleConfig *_config)
: KCModule (parent, name)
{
@@ -38,26 +38,26 @@ KForwmachPageConfig::KForwmachPageConfig( QWidget *parent, const char* name,
delete_config = false;
config = _config;
}
- forwmach_cb = new QCheckBox(i18n("Activate &forward"), this);
+ forwmach_cb = new TQCheckBox(i18n("Activate &forward"), this);
forwmach_cb->adjustSize();
- address_edit = new QLineEdit(this);
+ address_edit = new TQLineEdit(this);
address_edit->adjustSize();
address_edit->setMinimumWidth(150);
- address_label = new QLabel(address_edit,i18n("&Destination (user or user@host):"),this);
+ address_label = new TQLabel(address_edit,i18n("&Destination (user or user@host):"),this);
address_label->adjustSize();
address_label->setAlignment( ShowPrefix | AlignVCenter );
- method_combo = new QComboBox(this);
+ method_combo = new TQComboBox(this);
method_combo->insertItem("FWA");
method_combo->insertItem("FWR");
method_combo->insertItem("FWT");
method_combo->adjustSize();
method_combo->setMinimumWidth(80);
- method_label = new QLabel(method_combo, i18n("Forward &method:"),this);
+ method_label = new TQLabel(method_combo, i18n("Forward &method:"),this);
method_label->adjustSize();
method_label->setAlignment( ShowPrefix | AlignVCenter );
- expl_label = new QLabel(i18n(
+ expl_label = new TQLabel(i18n(
"FWA: Forward announcement only. Direct connection. Not recommended.\n\
FWR: Forward all requests, changing info when necessary. Direct connection.\n\
FWT: Forward all requests and handle the talk request. No direct connection.\n\
@@ -75,12 +75,12 @@ See Help for further explanation.\n\
load();
- connect(forwmach_cb, SIGNAL(clicked()), this, SLOT(forwmachOnOff()));
+ connect(forwmach_cb, TQT_SIGNAL(clicked()), this, TQT_SLOT(forwmachOnOff()));
// emit changed(true) on changes
- connect(forwmach_cb, SIGNAL(clicked()), this, SLOT(slotChanged()));
- connect(address_edit, SIGNAL(textChanged(const QString&)), this, SLOT(slotChanged()));
- connect(method_combo, SIGNAL(activated(int)), this, SLOT(slotChanged()));
+ connect(forwmach_cb, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotChanged()));
+ connect(address_edit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotChanged()));
+ connect(method_combo, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotChanged()));
}
KForwmachPageConfig::~KForwmachPageConfig( ) {
@@ -100,9 +100,9 @@ void KForwmachPageConfig::slotChanged() {
emit changed(true);
}
-void KForwmachPageConfig::resizeEvent(QResizeEvent *) {
+void KForwmachPageConfig::resizeEvent(TQResizeEvent *) {
int h_txt = forwmach_cb->height(); // taken for the general label height
- int h_edt = address_edit->height(); // taken for the general QLineEdit height
+ int h_edt = address_edit->height(); // taken for the general TQLineEdit height
int spc = h_txt / 3;
int w = rect().width();
@@ -148,14 +148,14 @@ void KForwmachPageConfig::load() {
config->setGroup("ktalkd");
- QString forward = config->readEntry("Forward","unset");
+ TQString forward = config->readEntry("Forward","unset");
forwmach_cb->setChecked(forward!="unset");
if (forward != "unset" )
address_edit->setText(forward);
else
address_edit->setText("");
- QString forwardMethod = config->readEntry("ForwardMethod","FWR");
+ TQString forwardMethod = config->readEntry("ForwardMethod","FWR");
for (int i=0; i<method_combo->count(); i++)
if (forwardMethod == method_combo->text(i))
method_combo->setCurrentItem(i);